"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ProjectCleanupService = void 0;
const yok_1 = require("../common/yok");
const path = require("path");
const color_1 = require("../color");
class ProjectCleanupService {
    constructor($fs, $logger, $projectHelper, $terminalSpinnerService) {
        this.$fs = $fs;
        this.$logger = $logger;
        this.$projectHelper = $projectHelper;
        this.$terminalSpinnerService = $terminalSpinnerService;
    }
    clean(pathsToClean) {
        return __awaiter(this, void 0, void 0, function* () {
            this.spinner = this.$terminalSpinnerService.createSpinner();
            let success = true;
            for (const pathToClean of pathsToClean) {
                const isCleaned = yield this.cleanPath(pathToClean).catch((error) => {
                    this.$logger.trace(`Encountered error while cleaning. Error is: ${error.message}.`, error);
                    return false;
                });
                success = success && isCleaned;
            }
            console.log();
            return success;
        });
    }
    cleanPath(pathToClean) {
        return __awaiter(this, void 0, void 0, function* () {
            this.spinner.clear();
            let success = true;
            let fileType;
            if (!pathToClean || pathToClean.trim().length === 0) {
                this.$logger.trace("cleanPath called with no pathToClean.");
                return success;
            }
            const filePath = path.resolve(this.$projectHelper.projectDir, pathToClean);
            const displayPath = color_1.color.yellow(`${path.relative(this.$projectHelper.projectDir, filePath)}`);
            this.$logger.trace(`Trying to clean '${filePath}'`);
            if (this.$fs.exists(filePath)) {
                const stat = this.$fs.getFsStats(filePath);
                if (stat.isDirectory()) {
                    this.$logger.trace(`Path '${filePath}' is a directory, deleting.`);
                    this.$fs.deleteDirectorySafe(filePath);
                    fileType = "directory";
                }
                else {
                    this.$logger.trace(`Path '${filePath}' is a file, deleting.`);
                    this.$fs.deleteFile(filePath);
                    fileType = "file";
                }
                success = !this.$fs.exists(filePath);
                if (success) {
                    this.spinner.succeed(`Cleaned ${fileType} ${displayPath}`);
                }
                else {
                    const message = color_1.color.red(`Failed to Clean ${fileType}`);
                    this.spinner.fail(`${message} ${displayPath}`);
                }
                return success;
            }
            this.$logger.trace(`Path '${filePath}' not found, skipping.`);
            this.spinner.info(`Skipping ${displayPath} because it doesn't exist.`);
            return success;
        });
    }
}
exports.ProjectCleanupService = ProjectCleanupService;
yok_1.injector.register("projectCleanupService", ProjectCleanupService);
